window.Gleam.initSearch([{"doc":"counter","title":"counter","content":"# counter\n\n[![Package Version](https://img.shields.io/hexpm/v/counter)](https://hex.pm/packages/counter)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/counter/)\n\n```sh\ngleam add counter\n```\n```gleam\nimport counter\nimport gleam/io\n\npub fn main() {\n  let c = [&quot;dog&quot;, &quot;cat&quot;, &quot;mouse&quot;, &quot;dog&quot;, &quot;dog&quot;, &quot;cat&quot;] |&gt; counter.from_list\n\n  c |&gt; counter.most_common |&gt; io.debug\n  // [#(&quot;dog&quot;, 3), #(&quot;cat&quot;, 2), #(&quot;mouse&quot;, 1)]\n\n  c |&gt; counter.unique_size |&gt; io.debug\n  // 3\n\n  c |&gt; counter.total |&gt; io.debug\n  // 6\n\n  c |&gt; counter.get(&quot;horse&quot;) |&gt; io.debug\n  // 0\n\n  let c = c |&gt; counter.insert(&quot;horse&quot;)\n\n  c |&gt; counter.get(&quot;horse&quot;) |&gt; io.debug\n  // 1\n\n  c |&gt; counter.keys |&gt; io.debug\n  // [&quot;cat&quot;, &quot;dog&quot;, &quot;horse&quot;, &quot;mouse&quot;]\n\n  c |&gt; counter.elements |&gt; io.debug\n  // [&quot;mouse&quot;, &quot;horse&quot;, &quot;dog&quot;, &quot;dog&quot;, &quot;dog&quot;, &quot;cat&quot;, &quot;cat&quot;]\n}\n```\n","url":"index.html"},{"doc":"counter","title":"Counter","content":"pub opaque type Counter(a)\n A `Counter` is a specialized dictionary used for counting the occurrences of items. `Counter` is implemented using the `gleam/dict` module.\n\nSynonyms:\ncounter.Counter\ncounter Counter","url":"counter.html#Counter"},{"doc":"counter","title":"add","content":"pub fn add(\n  counter_1: Counter(a),\n  counter_2: Counter(a),\n) -&gt; Counter(a)\n Add the counts from two `Counter`s into a new `Counter`.\nSynonyms:\ncounter.add\ncounter add","url":"counter.html#add"},{"doc":"counter","title":"elements","content":"pub fn elements(counter: Counter(a)) -&gt; List(a)\n Returns a non-unique list of all the items in the `Counter`. Each item will be repeated in the list the number of times it was inserted into the `Counter`.\n Do not write code that relies on the order elements are returned by this function as it may change in later versions of Gleam or Erlang.\nSynonyms:\ncounter.elements\ncounter elements","url":"counter.html#elements"},{"doc":"counter","title":"from_dict","content":"pub fn from_dict(d: Dict(a, Int)) -&gt; Counter(a)\n Creates a `Counter` from a `gleam/dict` of item-count pairs.\nSynonyms:\ncounter.from_dict\ncounter from_dict","url":"counter.html#from_dict"},{"doc":"counter","title":"from_list","content":"pub fn from_list(items: List(a)) -&gt; Counter(a)\n Creates a `Counter` from a list of items.\nSynonyms:\ncounter.from_list\ncounter from_list","url":"counter.html#from_list"},{"doc":"counter","title":"get","content":"pub fn get(counter: Counter(a), item: a) -&gt; Int\n Returns the number of times an item has been inserted into the `Counter`.\nSynonyms:\ncounter.get\ncounter get","url":"counter.html#get"},{"doc":"counter","title":"insert","content":"pub fn insert(counter: Counter(a), item: a) -&gt; Counter(a)\n Inserts an item into the `Counter`.\nSynonyms:\ncounter.insert\ncounter insert","url":"counter.html#insert"},{"doc":"counter","title":"keys","content":"pub fn keys(counter: Counter(a)) -&gt; List(a)\n Returns a list of all the unique items in the `Counter`.\n Do not write code that relies on the order keys are returned by this function as it may change in later versions of Gleam or Erlang.\nSynonyms:\ncounter.keys\ncounter keys","url":"counter.html#keys"},{"doc":"counter","title":"most_common","content":"pub fn most_common(counter: Counter(a)) -&gt; List(#(a, Int))\n Returns a list containing the item-count tuples, sorted by count in descending order.\n If `n` is `None`, the entire list is returned. If `n` is `Some`, a list the top `n` most-common items is returned.\n Returns a list containing all item-count tuples, sorted by count, in descending order.\nSynonyms:\ncounter.most_common\ncounter most_common","url":"counter.html#most_common"},{"doc":"counter","title":"most_common_n","content":"pub fn most_common_n(\n  counter: Counter(a),\n  n: Int,\n) -&gt; List(#(a, Int))\n Returns a list of item-count tuples containing the top n most frequent items, sorted by count, in descending order.\nSynonyms:\ncounter.most_common_n\ncounter most_common_n","url":"counter.html#most_common_n"},{"doc":"counter","title":"new","content":"pub fn new() -&gt; Counter(a)\n Creates a new empty `Counter`.\nSynonyms:\ncounter.new\ncounter new","url":"counter.html#new"},{"doc":"counter","title":"subtract","content":"pub fn subtract(\n  counter_1: Counter(a),\n  counter_2: Counter(a),\n) -&gt; Counter(a)\n Subtracts the counts in the second `Counter` from the first `Counter`, returning a new `Counter` with the results.\n Only items present in both `Counter`s will be used when subtracting counts from the first `Counter` and any item with a count of zero or less will be omitted from the new `Counter`.\nSynonyms:\ncounter.subtract\ncounter subtract","url":"counter.html#subtract"},{"doc":"counter","title":"to_dict","content":"pub fn to_dict(counter: Counter(a)) -&gt; Dict(a, Int)\n Returns the underlying `gleam/dict` of the `Counter`.\nSynonyms:\ncounter.to_dict\ncounter to_dict","url":"counter.html#to_dict"},{"doc":"counter","title":"to_list","content":"pub fn to_list(counter: Counter(a)) -&gt; List(#(a, Int))\n Returns a list of item-count tuples.\n Do not write code that relies on the order tuples are returned by this function as it may change in later versions of Gleam or Erlang.\nSynonyms:\ncounter.to_list\ncounter to_list","url":"counter.html#to_list"},{"doc":"counter","title":"total","content":"pub fn total(counter: Counter(a)) -&gt; Int\n Returns the sum of all counts in the `Counter`.\nSynonyms:\ncounter.total\ncounter total","url":"counter.html#total"},{"doc":"counter","title":"unique_size","content":"pub fn unique_size(counter: Counter(a)) -&gt; Int\n Returns the number of unique items in the `Counter`.\nSynonyms:\ncounter.unique_size\ncounter unique_size","url":"counter.html#unique_size"},{"doc":"counter","title":"update","content":"pub fn update(counter: Counter(a), items: List(a)) -&gt; Counter(a)\n Updates the `Counter` from a list of items.\nSynonyms:\ncounter.update\ncounter update","url":"counter.html#update"},{"doc":"counter","title":"values","content":"pub fn values(counter: Counter(a)) -&gt; List(Int)\n Returns a list of all the counts in the `Counter`.\n Do not write code that relies on the order values are returned by this function as it may change in later versions of Gleam or Erlang.\nSynonyms:\ncounter.values\ncounter values","url":"counter.html#values"},{"doc":"counter","title":"counter","content":"","url":"counter.html"}]);